pyairfoil package
=================

Submodules
----------

pyairfoil.cli module
--------------------

.. automodule:: pyairfoil.cli
    :members:
    :undoc-members:
    :show-inheritance:

pyairfoil.pyairfoil module
--------------------------

.. automodule:: pyairfoil.pyairfoil
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyairfoil
    :members:
    :undoc-members:
    :show-inheritance:
